@@ -16,15 +16,13 @@ def test_functional_boxed(testdir):
 class TestOptionEffects:
     def test_boxed_option_default(self, testdir):
         tmpdir = testdir.tmpdir.ensure("subdir", dir=1)
-        config = testdir.reparseconfig()
-        config.initsession()
+        config = testdir.parseconfig()
         assert not config.option.boxed
         py.test.importorskip("execnet")
-        config = testdir.reparseconfig(['-d', tmpdir])
-        config.initsession()
+        config = testdir.parseconfig('-d', tmpdir)
         assert not config.option.boxed
 
     def test_is_not_boxed_by_default(self, testdir):
-        config = testdir.reparseconfig([testdir.tmpdir])
+        config = testdir.parseconfig(testdir.tmpdir)
         assert not config.option.boxed
 
